local L = LibStub("AceLocale-3.0"):GetLocale("Skada", false)
local Skada = Skada
local mod = Skada:NewModule(L["DPS"].."+"..L["HPS"].."-"..L["DTPS"])

local function getHealplusDamageminusTaken(player)
      return (player.damage+player.healing-player.damagetaken)
end

local function getDPSplusHPSminusDTPS(set, player)
      local totaltime = Skada:PlayerActiveTime(set, player)
      return getHealplusDamageminusTaken(player) / math.max(1,totaltime)
end

local function getRaidDPSplusHPSminusDTPS(set)
      if set.time > 0 then
            return (set.damage+set.healing-set.damagetaken) / math.max(1, set.time)
      else
            local endtime = set.endtime
            if not endtime then
                  endtime = time()
            end
            return (set.damage+set.healing-set.damagetaken) / math.max(1, endtime - set.starttime)
      end
end

local function dpsplushpsminusdtps_tooltip(win, id, label, tooltip)
	local set = win:get_selected_set()
	local player = Skada:find_player(set, id)
	if player then
		local totaltime = Skada:PlayerActiveTime(set, player)
		tooltip:AddLine(player.name)
		tooltip:AddDoubleLine(L["Damage"]..":", Skada:FormatNumber(player.damage), 255,255,255,255,255,255)
		tooltip:AddDoubleLine(L["Healing"]..":", Skada:FormatNumber(player.healing), 255,255,255,0,255,0)
		tooltip:AddDoubleLine(L["DamageTaken"]..":", Skada:FormatNumber(player.damagetaken), 255,255,255,255,0,0)
	end
end

function mod:Update(win, set)
      local maxvalue = 0
      for i, player in ipairs(set.players) do
            local rw = getHealplusDamageminusTaken(player)
            if rw > maxvalue then
                  maxvalue = rw
            end
      end
      local nr = 1
      for i, player in ipairs(set.players) do
            if player.damage > 0 or player.healing > 0 or player.damagetaken > 0 then
                  local rw = getHealplusDamageminusTaken(player)
                  local mypercent = (player.damage+player.healing-player.damagetaken) / maxvalue
                  local percentformatted=(string.format("%02.1f%%", rw*100/(set.damage+set.healing-set.damagetaken)))
                  local d = win.dataset[nr] or {}
                  win.dataset[nr] = d
                  d.id = player.id
                  d.label = player.name
                  d.value = player.damage + player.healing - player.damagetaken
                  d.valuetext = Skada:FormatValueText(
                        Skada:FormatNumber(rw), self.metadata.columns.Damage,
                        Skada:FormatNumber(getDPSplusHPSminusDTPS(set, player)), self.metadata.columns.DPS,
                        percentformatted, self.metadata.columns.Percent
                        )
                  d.class = player.class
                  d.role = player.role
                  nr = nr + 1
            end
      end
      win.metadata.maxvalue = maxvalue

end

function mod:OnEnable()
      mod.metadata = {tooltip = dpsplushpsminusdtps_tooltip, columns = {Damage= true, DPS = true, Percent = true}}
      Skada:AddMode(self)
end

function mod:OnDisable()
      Skada:RemoveMode(self)
end

function mod:GetSetSummary(set)
      return Skada:FormatValueText(
            Skada:FormatNumber(set.damage+set.healing-set.damagetaken), self.metadata.columns.Damage,
            Skada:FormatNumber(getRaidDPSplusHPSminusDTPS(set)), self.metadata.columns.DPS
            )
end
